@@ -1,6 +1,6 @@
 package swat;
 
-our $VERSION = '0.1.64';
+our $VERSION = '0.1.65';
 
 use base 'Exporter'; 
 
@@ -20,7 +20,7 @@ use Test::More;
 use Data::Dumper;
 use File::Temp qw/ tempfile /;
 use swat::story;
-
+use Carp;
 
 sub execute_with_retry {
 
@@ -120,21 +120,33 @@ sub header {
 
 sub generate_asserts {
 
+
     my $check_file = shift;
 
     header() if debug_mod12();
 
-    dsl->{debug_mod} = get_prop('debug');
+    dsl()->{debug_mod} = get_prop('debug');
 
     dsl()->{match_l} = get_prop('match_l');
 
     dsl()->{output} = make_http_request();
 
-    dsl()->generate_asserts($check_file);
+    eval {
+        dsl()->validate($check_file);
+    };
+
+    my $err = $@;
+
+    for my $r ( @{dsl()->results}){
+        ok($r->{status}, $r->{message}) if $r->{type} eq 'check_expression';
+        diag($r->{message}) if $r->{type} eq 'debug';
+
+    }
+
+    confess "parser error: $err" if $err;
 
 }
 
-
 1;
 
 
@@ -496,8 +508,7 @@ You may use regular expressions as well:
     # swat output
     OK - output matches /\d\d\d\d-\d\d-\d\d/
 
-Follow L<https://github.com/melezhik/outthentic-dsl#comments-blank-lines-and-text-blocks|https://github.com/melezhik/outthentic-dsl#comments-blank-lines-and-text-blocks>
-to know more.
+Follow L<https://github.com/melezhik/outthentic-dsl#check-expressions|https://github.com/melezhik/outthentic-dsl#check-expressions> to know more.
 
 =over
 
@@ -527,8 +538,7 @@ Yes you may generate new check list on run time:
     hello
     again
 
-Follow L<https://github.com/melezhik/outthentic-dsl#generators|https://github.com/melezhik/outthentic-dsl#generators>
-to know more.
+Follow L<https://github.com/melezhik/outthentic-dsl#generators|https://github.com/melezhik/outthentic-dsl#generators> to know more.
 
 =over
 
@@ -543,10 +553,9 @@ What about inline arbitrary perl code? Well, it's easy!
 
     # check list
     regexp: number: (\d+)
-    code: cmp_ok( capture()->[0], '>=', 0, 'got none zero number');
+    validator: [ ( capture()->[0] '>=' 0 ), 'got none zero number') ];
 
-Follow L<https://github.com/melezhik/outthentic-dsl#perl-expressions|https://github.com/melezhik/outthentic-dsl#perl-expressions>
-to know more.
+Follow L<https://github.com/melezhik/outthentic-dsl#validators|https://github.com/melezhik/outthentic-dsl#validators> to know more.
 
 =over
 
@@ -665,14 +674,35 @@ C<prove_options> - prove options to be passed to prove runner,  default value is
 
 =item *
 
-C<debug> - set to `1,2,3' if you want to see debug information in output, default value is `0'.
-Increasing debug value means more low level information appeared at console.
+C<debug> - enable swat debugging
+
+=over
+
+=item *
+
+Increasing debug value results in more low level information appeared at output
 
 
 
 =item *
 
-C<debug_bytes> - number of bytes of http response  to be dumped out when debug is on. default value is `500'.
+Default value is 0, which means no debugging
+
+
+
+=item *
+
+Possible values: 0,1,2,3
+
+
+
+=back
+
+
+
+=item *
+
+C<debug_bytes> - number of bytes of http response to be dumped out when debug is on. default value is `500'.
 
 
 
@@ -902,7 +932,7 @@ This is an example of setting server response inside swat hook:
     set_response("THIS IS I FAKE RESPONSE\n HELLO WORLD");
     
     # get.txt
-    THIS IS FAKE RESPONSE
+    THIS IS A FAKE RESPONSE
     HELLO WORLD
 
 Another interesting idea about set_response feature is a I<conditional> http requests.
@@ -1148,7 +1178,7 @@ ODO makes validation of given stdout against given check list
 
 =item *
 
-validation results in a I<sequence> of Test::More ok() asserts
+validation results are turned into a I<sequence> of Test::More ok() asserts
 
 
 =back
